# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import winrt.system
from winrt import _winrt_windows_phone_devices_notification

__all__ = [
    "VibrationDevice",
]

VibrationDevice = _winrt_windows_phone_devices_notification.VibrationDevice
